pitchtools.IntervalObjectClass
==============================

.. abjad-lineage:: abjad.tools.pitchtools.IntervalObjectClass.IntervalObjectClass.IntervalObjectClass

.. autoclass:: abjad.tools.pitchtools.IntervalObjectClass.IntervalObjectClass.IntervalObjectClass
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.IntervalObjectClass.IntervalObjectClass.IntervalObjectClass.number
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.IntervalObjectClass.IntervalObjectClass.IntervalObjectClass.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.pitchtools.IntervalObjectClass.IntervalObjectClass.IntervalObjectClass.__abs__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalObjectClass.IntervalObjectClass.IntervalObjectClass.__eq__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalObjectClass.IntervalObjectClass.IntervalObjectClass.__float__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalObjectClass.IntervalObjectClass.IntervalObjectClass.__ge__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalObjectClass.IntervalObjectClass.IntervalObjectClass.__gt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalObjectClass.IntervalObjectClass.IntervalObjectClass.__hash__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalObjectClass.IntervalObjectClass.IntervalObjectClass.__int__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalObjectClass.IntervalObjectClass.IntervalObjectClass.__le__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalObjectClass.IntervalObjectClass.IntervalObjectClass.__lt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalObjectClass.IntervalObjectClass.IntervalObjectClass.__ne__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalObjectClass.IntervalObjectClass.IntervalObjectClass.__repr__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalObjectClass.IntervalObjectClass.IntervalObjectClass.__str__
   :noindex:
